vlc | branch: master | Marvin Scholz <epira...@gmail.com> | Wed Aug  9 14:23:43 
2017 +0200| [dd876ac106bee892fb5ccc7823cfc7e2a101573c] | committer: Marvin 
Scholz

macosx: Rename VLCDebugMessageWindowController to VLCLogWindowController

This name is much shorter and a lot easier to understand, as it is less
likely to be confused with the error messages window stuff.

> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=dd876ac106bee892fb5ccc7823cfc7e2a101573c
---

 extras/package/macosx/VLC.xcodeproj/project.pbxproj          | 12 ++++++------
 modules/gui/macosx/Makefile.am                               |  2 +-
 modules/gui/macosx/UI/LogMessageWindow.xib                   |  2 +-
 ...bugMessageWindowController.h => VLCLogWindowController.h} |  4 ++--
 ...bugMessageWindowController.m => VLCLogWindowController.m} | 10 +++++-----
 modules/gui/macosx/VLCMain.h                                 |  4 ++--
 modules/gui/macosx/VLCMain.m                                 |  8 ++++----
 modules/gui/macosx/VLCMainMenu.m                             |  2 +-
 8 files changed, 22 insertions(+), 22 deletions(-)

diff --git a/extras/package/macosx/VLC.xcodeproj/project.pbxproj 
b/extras/package/macosx/VLC.xcodeproj/project.pbxproj
index bfea595b2d..c7e4c23115 100644
--- a/extras/package/macosx/VLC.xcodeproj/project.pbxproj
+++ b/extras/package/macosx/VLC.xcodeproj/project.pbxproj
@@ -21,7 +21,7 @@
                1C3113A11E508C6900D4DD76 /* VLCConvertAndSaveWindowController.m 
in Sources */ = {isa = PBXBuildFile; fileRef = CC0663351566C34C003A411C /* 
VLCConvertAndSaveWindowController.m */; };
                1C3113A31E508C6900D4DD76 /* VLCCoreDialogProvider.m in Sources 
*/ = {isa = PBXBuildFile; fileRef = CC4A33210F8CB017000FC4A7 /* 
VLCCoreDialogProvider.m */; };
                1C3113A51E508C6900D4DD76 /* VLCCoreInteraction.m in Sources */ 
= {isa = PBXBuildFile; fileRef = CC448A6113B68A0B009F72E0 /* 
VLCCoreInteraction.m */; };
-               1C3113A71E508C6900D4DD76 /* VLCDebugMessageWindowController.m 
in Sources */ = {isa = PBXBuildFile; fileRef = 7D8BB0B418302AC000FAE9B7 /* 
VLCDebugMessageWindowController.m */; };
+               1C3113A71E508C6900D4DD76 /* VLCLogWindowController.m in Sources 
*/ = {isa = PBXBuildFile; fileRef = 7D8BB0B418302AC000FAE9B7 /* 
VLCLogWindowController.m */; };
                1C3113A91E508C6900D4DD76 /* VLCDocumentController.m in Sources 
*/ = {isa = PBXBuildFile; fileRef = 1C39ABBD1DA9AB9B00FE052A /* 
VLCDocumentController.m */; };
                1C3113AB1E508C6900D4DD76 /* VLCExtensionsDialogProvider.m in 
Sources */ = {isa = PBXBuildFile; fileRef = 5CCED71114C0D4A90057F8D1 /* 
VLCExtensionsDialogProvider.m */; };
                1C3113AD1E508C6900D4DD76 /* VLCExtensionsManager.m in Sources 
*/ = {isa = PBXBuildFile; fileRef = 5CCED71314C0D4A90057F8D1 /* 
VLCExtensionsManager.m */; };
@@ -664,8 +664,8 @@
                7D871D371B5E6844000B56C0 /* VLCMain+OldPrefs.h */ = {isa = 
PBXFileReference; lastKnownFileType = sourcecode.c.h; path = 
"VLCMain+OldPrefs.h"; sourceTree = "<group>"; };
                7D871D381B5E6844000B56C0 /* VLCMain+OldPrefs.m */ = {isa = 
PBXFileReference; lastKnownFileType = sourcecode.c.objc; path = 
"VLCMain+OldPrefs.m"; sourceTree = "<group>"; };
                7D871D391B5E684D000B56C0 /* helpers.h */ = {isa = 
PBXFileReference; lastKnownFileType = sourcecode.c.h; path = helpers.h; 
sourceTree = "<group>"; };
-               7D8BB0B318302AC000FAE9B7 /* VLCDebugMessageWindowController.h 
*/ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.h; path = 
VLCDebugMessageWindowController.h; sourceTree = "<group>"; };
-               7D8BB0B418302AC000FAE9B7 /* VLCDebugMessageWindowController.m 
*/ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.objc; path = 
VLCDebugMessageWindowController.m; sourceTree = "<group>"; };
+               7D8BB0B318302AC000FAE9B7 /* VLCLogWindowController.h */ = {isa 
= PBXFileReference; lastKnownFileType = sourcecode.c.h; path = 
VLCLogWindowController.h; sourceTree = "<group>"; };
+               7D8BB0B418302AC000FAE9B7 /* VLCLogWindowController.m */ = {isa 
= PBXFileReference; lastKnownFileType = sourcecode.c.objc; path = 
VLCLogWindowController.m; sourceTree = "<group>"; };
                7D9516B81C60B6AB00D14E1A /* VLCStatusBarIcon.h */ = {isa = 
PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = 
VLCStatusBarIcon.h; sourceTree = "<group>"; };
                7D9516B91C60B6AB00D14E1A /* VLCStatusBarIcon.m */ = {isa = 
PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path 
= VLCStatusBarIcon.m; sourceTree = "<group>"; };
                7DA481221B5FC13700917FD7 /* VLCPlaylistView.h */ = {isa = 
PBXFileReference; lastKnownFileType = sourcecode.c.h; path = VLCPlaylistView.h; 
sourceTree = "<group>"; };
@@ -859,8 +859,8 @@
                                CC4A33210F8CB017000FC4A7 /* 
VLCCoreDialogProvider.m */,
                                CC448A6013B68A0B009F72E0 /* 
VLCCoreInteraction.h */,
                                CC448A6113B68A0B009F72E0 /* 
VLCCoreInteraction.m */,
-                               7D8BB0B318302AC000FAE9B7 /* 
VLCDebugMessageWindowController.h */,
-                               7D8BB0B418302AC000FAE9B7 /* 
VLCDebugMessageWindowController.m */,
+                               7D8BB0B318302AC000FAE9B7 /* 
VLCLogWindowController.h */,
+                               7D8BB0B418302AC000FAE9B7 /* 
VLCLogWindowController.m */,
                                1C39ABBC1DA9AB9B00FE052A /* 
VLCDocumentController.h */,
                                1C39ABBD1DA9AB9B00FE052A /* 
VLCDocumentController.m */,
                                5CCED71014C0D4A90057F8D1 /* 
VLCExtensionsDialogProvider.h */,
@@ -1788,7 +1788,7 @@
                                1C3113A31E508C6900D4DD76 /* 
VLCCoreDialogProvider.m in Sources */,
                                6B2EFC631F281A0900F3C0EA /* 
VLCVolumeSliderCell.m in Sources */,
                                1C3113A51E508C6900D4DD76 /* 
VLCCoreInteraction.m in Sources */,
-                               1C3113A71E508C6900D4DD76 /* 
VLCDebugMessageWindowController.m in Sources */,
+                               1C3113A71E508C6900D4DD76 /* 
VLCLogWindowController.m in Sources */,
                                6BF5C5071EFE7E58008A9C12 /* 
VLCTintedImageButtonCell.m in Sources */,
                                1C3113A91E508C6900D4DD76 /* 
VLCDocumentController.m in Sources */,
                                1C3113AB1E508C6900D4DD76 /* 
VLCExtensionsDialogProvider.m in Sources */,
diff --git a/modules/gui/macosx/Makefile.am b/modules/gui/macosx/Makefile.am
index e4be71eed7..c24c902eea 100644
--- a/modules/gui/macosx/Makefile.am
+++ b/modules/gui/macosx/Makefile.am
@@ -71,7 +71,7 @@ libmacosx_plugin_la_SOURCES = \
        gui/macosx/VLCAudioEffectsWindowController.h 
gui/macosx/VLCAudioEffectsWindowController.m \
        gui/macosx/VLCBookmarksWindowController.h 
gui/macosx/VLCBookmarksWindowController.m \
        gui/macosx/VLCCoreDialogProvider.h gui/macosx/VLCCoreDialogProvider.m \
-       gui/macosx/VLCDebugMessageWindowController.h 
gui/macosx/VLCDebugMessageWindowController.m \
+       gui/macosx/VLCLogWindowController.h gui/macosx/VLCLogWindowController.m 
\
        gui/macosx/VLCHUDSliderCell.h gui/macosx/VLCHUDSliderCell.m \
        gui/macosx/VLCHUDButtonCell.h gui/macosx/VLCHUDButtonCell.m \
        gui/macosx/VLCHUDCheckboxCell.h gui/macosx/VLCHUDCheckboxCell.m \
diff --git a/modules/gui/macosx/UI/LogMessageWindow.xib 
b/modules/gui/macosx/UI/LogMessageWindow.xib
index 73ee0c0a2b..98c0758ea9 100644
--- a/modules/gui/macosx/UI/LogMessageWindow.xib
+++ b/modules/gui/macosx/UI/LogMessageWindow.xib
@@ -5,7 +5,7 @@
         <plugIn identifier="com.apple.InterfaceBuilder.CocoaPlugin" 
version="12120"/>
     </dependencies>
     <objects>
-        <customObject id="-2" userLabel="File's Owner" 
customClass="VLCDebugMessageWindowController">
+        <customObject id="-2" userLabel="File's Owner" 
customClass="VLCLogWindowController">
             <connections>
                 <outlet property="arrayController" destination="0Or-bh-QJU" 
id="Wo9-Rk-Jkb"/>
                 <outlet property="detailView" destination="ESj-Mw-X94" 
id="YDo-hQ-k1t"/>
diff --git a/modules/gui/macosx/VLCMain.h b/modules/gui/macosx/VLCMain.h
index 4db72bda63..5ffd2a5649 100644
--- a/modules/gui/macosx/VLCMain.h
+++ b/modules/gui/macosx/VLCMain.h
@@ -68,7 +68,7 @@ static NSString * 
VLCMediaKeySupportSettingChangedNotification = @"VLCMediaKeySu
 @class VLCCoreDialogProvider;
 @class VLCBookmarksWindowController;
 @class VLCOpenWindowController;
-@class VLCDebugMessageWindowController;
+@class VLCLogWindowController;
 @class VLCTrackSynchronizationWindowController;
 @class VLCAudioEffectsWindowController;
 @class VLCVideoEffectsWindowController;
@@ -99,7 +99,7 @@ static NSString * 
VLCMediaKeySupportSettingChangedNotification = @"VLCMediaKeySu
 - (VLCExtensionsManager *)extensionsManager;
 - (VLCStatusBarIcon *)statusBarIcon;
 
-- (VLCDebugMessageWindowController *)debugMsgPanel;
+- (VLCLogWindowController *)debugMsgPanel;
 
 - (VLCTrackSynchronizationWindowController *)trackSyncPanel;
 - (VLCAudioEffectsWindowController *)audioEffectsPanel;
diff --git a/modules/gui/macosx/VLCMain.m b/modules/gui/macosx/VLCMain.m
index 43c8849534..965cb02ea3 100644
--- a/modules/gui/macosx/VLCMain.m
+++ b/modules/gui/macosx/VLCMain.m
@@ -58,7 +58,7 @@
 #import "VLCTrackSynchronizationWindowController.h"
 #import "VLCExtensionsManager.h"
 #import "VLCResumeDialogController.h"
-#import "VLCDebugMessageWindowController.h"
+#import "VLCLogWindowController.h"
 #import "VLCConvertAndSaveWindowController.h"
 
 #import "VLCVideoEffectsWindowController.h"
@@ -174,7 +174,7 @@ static int ShowController(vlc_object_t *p_this, const char 
*psz_variable,
     VLCResumeDialogController *_resume_dialog;
     VLCInputManager *_input_manager;
     VLCPlaylist *_playlist;
-    VLCDebugMessageWindowController *_messagePanelController;
+    VLCLogWindowController *_messagePanelController;
     VLCStatusBarIcon *_statusBarIcon;
     VLCTrackSynchronizationWindowController *_trackSyncPanel;
     VLCAudioEffectsWindowController *_audioEffectsPanel;
@@ -498,10 +498,10 @@ static VLCMain *sharedInstance = nil;
     return _extensionsManager;
 }
 
-- (VLCDebugMessageWindowController *)debugMsgPanel
+- (VLCLogWindowController *)debugMsgPanel
 {
     if (!_messagePanelController)
-        _messagePanelController = [[VLCDebugMessageWindowController alloc] 
init];
+        _messagePanelController = [[VLCLogWindowController alloc] init];
 
     return _messagePanelController;
 }
diff --git a/modules/gui/macosx/VLCMainMenu.m b/modules/gui/macosx/VLCMainMenu.m
index 67b6cb0fcb..38b329183e 100644
--- a/modules/gui/macosx/VLCMainMenu.m
+++ b/modules/gui/macosx/VLCMainMenu.m
@@ -46,7 +46,7 @@
 #import "VLCMainWindowControlsBar.h"
 #import "VLCExtensionsManager.h"
 #import "VLCConvertAndSaveWindowController.h"
-#import "VLCDebugMessageWindowController.h"
+#import "VLCLogWindowController.h"
 #import "VLCAddonsWindowController.h"
 #import "VLCTimeSelectionPanelController.h"
 #import "NSScreen+VLCAdditions.h"

_______________________________________________
vlc-commits mailing list
vlc-commits@videolan.org
https://mailman.videolan.org/listinfo/vlc-commits

Reply via email to
diff --git a/modules/gui/macosx/VLCDebugMessageWindowController.h 
b/modules/gui/macosx/VLCLogWindowController.h
similarity index 92%
rename from modules/gui/macosx/VLCDebugMessageWindowController.h
rename to modules/gui/macosx/VLCLogWindowController.h
index 075e90ddc6..6ed196c374 100644
--- a/modules/gui/macosx/VLCDebugMessageWindowController.h
+++ b/modules/gui/macosx/VLCLogWindowController.h
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * VLCDebugMessageWindowController.m: Mac OS X interface crash reporter
  *****************************************************************************
  * Copyright (C) 2004-2013 VLC authors and VideoLAN
  * $Id$
@@ -25,7 +25,7 @@
 
 #import <Cocoa/Cocoa.h>
 
-@interface VLCDebugMessageWindowController : NSWindowController
+@interface VLCLogWindowController : NSWindowController
 
 @property (assign) IBOutlet NSTableView *messageTable;
 @property (assign) IBOutlet NSButton *saveButton;
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * VLCDebugMessageWindowController.m: Mac OS X interface crash reporter
+ * VLCLogWindowController.h: Mac OS X interface crash reporter
  *****************************************************************************
  * Copyright (C) 2004-2013 VLC authors and VideoLAN
diff --git a/modules/gui/macosx/VLCDebugMessageWindowController.m 
b/modules/gui/macosx/VLCLogWindowController.m
similarity index 97%
rename from modules/gui/macosx/VLCDebugMessageWindowController.m
rename to modules/gui/macosx/VLCLogWindowController.m
index 55752ccada..607d88e52a 100644
--- a/modules/gui/macosx/VLCDebugMessageWindowController.m
+++ b/modules/gui/macosx/VLCLogWindowController.m
@@ -1,5 +1,5 @@
 /*****************************************************************************
  * VLCDebugMessageWindowController.m: Mac OS X interface crash reporter
  *****************************************************************************
  * Copyright (C) 2004-2013 VLC authors and VideoLAN
  * $Id$
@@ -23,11 +23,11 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, 
USA.
  *****************************************************************************/
 
-#import "VLCDebugMessageWindowController.h"
+#import "VLCLogWindowController.h"
 #import "VLCMain.h"
 #import <vlc_common.h>
 
-@interface VLCDebugMessageWindowController () <NSWindowDelegate>
+@interface VLCLogWindowController () <NSWindowDelegate>
 
 /* This array stores messages that are managed by the arrayController */
 @property (retain) NSMutableArray *messagesArray;
@@ -56,7 +56,7 @@ static void MsgCallback(void *data, int type, const vlc_log_t 
*item, const char
     @autoreleasepool {
         int state;
         char *msg;
-        VLCDebugMessageWindowController *controller = (__bridge 
VLCDebugMessageWindowController*)data;
+        VLCLogWindowController *controller = (__bridge 
VLCLogWindowController*)data;
         static NSString *types[4] = { @"info", @"error", @"warning", @"debug" 
};
 
         if (vasprintf(&msg, format, ap) == -1) {
@@ -82,7 +82,7 @@ static void MsgCallback(void *data, int type, const vlc_log_t 
*item, const char
     }
 }
 
-@implementation VLCDebugMessageWindowController
+@implementation VLCLogWindowController
 
 - (id)init
 {
@@ -1,5 +1,5 @@
 /*****************************************************************************
- * VLCDebugMessageWindowController.m: Mac OS X interface crash reporter
+ * VLCLogWindowController.m: Mac OS X interface crash reporter
  *****************************************************************************
  * Copyright (C) 2004-2013 VLC authors and VideoLAN